//!	commands accessible from within a session

use tmux_interface::{
	Tmux,
	commands
};

use crate::{
	error,
	state::State,
	util
};

pub fn path(state: &mut State) {
	state.session_enforce("path");

	let message = commands::DisplayMessage::new().print().message("#{session_path}");

	let result = Tmux::new().add_command(message).output().unwrap();
	let text = String::from_utf8(result.0.stdout);

	if let Ok(output) = text {
		//	trim the trailing line break
		let target = output.len() - 1;
		println!("{}", &output[0..target]);
	}
}

pub fn switch(state: &mut State) {
	util::terminal_enforce();
	//	refuse to run outside a session
	state.session_enforce("switch");

	//	consume optional flags
	let read_only = state.flags.read_only;
	//TODO: -d flag handling needs to be done manually

	let args = state.args.clone().finish();
	if args.len() < 1 { error::missing_target(); }
	let target = args.get(0).unwrap().to_string_lossy().to_string();

	let exists = util::session_exists(target.clone());
	if !exists { error::no_target(target.clone()); }

	let mut switch = commands::SwitchClient::new();
	switch = switch.target_session(target);
	if read_only { switch.read_only = true; }

	Tmux::new()
		.add_command(switch)
		.output().ok();
}

pub fn title(state: State) {
	state.session_enforce("title");
	if let Some(title) = state.title { println!("{title}"); }
}

