
use pico_args::Arguments;

type Flag = [&'static str;2];

pub static DETACH: Flag		= ["-d", "--detach"];
pub static HELP: Flag		= ["-h", "--help"];
pub static NEST: Flag		= ["-n", "--nest"];
pub static QUIET: Flag		= ["-q", "--quiet"];
pub static READ_ONLY: Flag	= ["-r", "--read-only"];
pub static TARGET: Flag		= ["-t", "--target"];
pub static VERSION: Flag	= ["-v", "--version"];

pub struct Flags {
	pub detached: bool,
	pub nested: bool,
	pub quiet: bool,
	pub read_only: bool,
	pub target: Option<String>,
}

impl Flags {

	pub fn from(args: &mut Arguments) -> Flags {
		let detached	= args.contains(DETACH);
		let nested		= args.contains(NEST);
		let quiet		= args.contains(QUIET);
		let read_only	= args.contains(READ_ONLY);
		let target		= args.value_from_str(TARGET).ok();

		Flags {
			detached,
			nested,
			quiet,
			read_only,
			target
		}
	}

	pub fn clone(&self) -> Flags {
		Flags {
			detached: self.detached,
			nested: self.nested,
			quiet: self.quiet,
			read_only: self.read_only,
			target: None
		}
	}

}

